% read_waveforms    - Read out 4 acquisition channels

function data = read_ddc_waveforms(sys, dev)

base=[sys, ':', dev, ':'];

pvs={'DDCPROC.VALH'; 'ACQ:DDC:TSC'};
pvs = strcat(base, pvs);
vals = lcaGet(pvs);

x = vals(1,2:end);
N = double(lcaGetNelem(sprintf('%sACQ:DDC:TSC', base)));
M = 2*N;
data.acq_id = vals(1,1);
for k=1:4
  data.chan(:,k) = x((k-1)*M+1:k*M)';
end
data.t = vals(2,1:N)';
data.sel = lcaGet([base, 'ACQ:SEL'], 1, 'byte');
data.ddc_acq = lcaGet([base, 'ACQ:DDC_ACQ'], 1, 'byte');
data.sys = sys;
data.dev = dev;

% Collect calibration information
pvs = {'FSAMP'; 'REF:DDS:FREQ'; 'ACQ:POSTLEN'; 'ACQ:DDC_CNT'};

k = 1;
for ch=0:2
  pvs = [pvs; sprintf('CH%d:SCALE', ch)];
  pvs = [pvs; sprintf('CH%d:PH_OFFSET', ch)];
  pvs = [pvs; sprintf('CH%d:HWPH', ch)];
  pvc{k}   = sprintf('CH%d:PWRSW', ch);
  pvc{k+1} = sprintf('CH%d:UNITS', ch);
  pvc{k+2} = sprintf('CH%d:LABEL', ch);
  k = k + 3;
end
pvs = strcat(base, pvs);
vals = lcaGet(pvs);

data.fs      = vals(1)*1e6;
data.fif     = vals(2)*1e3;
data.postlen = vals(3);
data.ddc_cnt = vals(4);
data.theta = data.fif / data.fs * 2 * pi;
[M N] = rat(data.fif/data.fs);
data.nfilt = N;

data.scale     = vals(5:3:13);
data.ph_offset = vals(6:3:13);
data.hwph      = vals(7:3:13);

strings = lcaGet(strcat(base, pvc(:)));
data.pwrsw=strings(1:3:end);
data.units=strings(2:3:end);
data.labels=strings(3:3:end);

% Plot
if (nargout == 0)
  plot_waveforms(data);
end
